import { Struct } from "./modules/api/struct/struct";
import { Project } from "./modules/api/project/project";
import { Sort } from "./modules/types/sort";
import { Authorization } from "./modules/api/authorization/authorization";
import { Company } from "./modules/api/company/company";
import { Common } from "./modules/api/struct/common/common";
import { Custom } from "./modules/api/struct/custom/custom";
import { Flow } from "./modules/api/flow/flow";
import { PreviousStep } from "./modules/api/step/previous-step";
import { Step } from "./modules/api/step/step";
import { NextStep } from "./modules/api/step/next-step";
import { Stage } from "./modules/api/stage/stage";
import { Token } from "./modules/token/token";
import { Organization } from "./modules/api/organization/organization";
export declare class ApipassSDK {
    static readonly PROJECT_NAME = "EMBEDDED";
    static readonly STAGE_NAME = "EMBEDDED";
    static readonly STAGE_DESCRIPTION = "Embedded Stage";
    static loading: boolean;
    static externalClientId: string;
    static externalClientName: string;
    static externalClientEmail: string;
    static currentToken: string | undefined;
    static organizationToken: string | undefined;
    static companyToken: string | undefined;
    static embeddedCompany: Company | undefined;
    static embeddedOrganizationCompany: Company | undefined;
    static embeddedOrganization: Organization | undefined;
    static embeddedStage: Stage | undefined;
    static embeddedProject: Project | undefined;
    static organizationTokenSession: Token;
    static companyTokenSession: Token;
    private static tokenService;
    private static organizationService;
    private static companyService;
    private static authorizationService;
    private static projectService;
    private static commonService;
    private static customService;
    private static structService;
    private static flowService;
    private static stageService;
    private static getTokenSession;
    private static processAsyncInit;
    private static initClientCompany;
    private static initOrganization;
    /**
     * Init ApipassSDK.
     * @method
     * @param {string} jwtToken - Your JWTToken to authenticate in APIPASS.
     * @param externalClientId - Your external client id.
     * @param externalClientName - Your external client name.
     * @param externalClientEmail - Your external client email.
     * @throws InvalidTokenException - if jwtToken is not present or is invalid.
     */
    static init(jwtToken: string, externalClientId: string, externalClientName: string, externalClientEmail: string): Promise<void>;
    /**
     * Find your company.
     * @async
     * @method
     * @returns company - returns promise with your company
     */
    static findCompany(id: string): Promise<Company | undefined>;
    /**
     * Find all authorizations.
     * @async
     * @method
     * @returns Authorization - returns promise with Array of authorizations
     */
    static findAllAuthorizations(): Promise<Array<Authorization> | undefined>;
    /**
     * Find all authorizations by filters.
     * @async
     * @param projectId: string (id of project to filter)
     * @param provider: string (provider of authorization)
     * @param withoutProjectId: boolean (ignore relation of project)
     * @method
     * @returns Authorization - returns promise with Array of authorizations
     */
    static findAllAuthorizationsByExample(projectId: string, provider: string, withoutProjectId: boolean): Promise<Array<Authorization> | undefined>;
    /**
     * Find authorizations by id.
     * @async
     * @param id: string (id of authorization to find)
     * @method
     * @returns Authorization - returns promise with authorization
     */
    static findAuthorization(id: string): Promise<Authorization | undefined>;
    /**
     * Delete Authorization.
     * @async
     * @param authorization: Authorization (object to delete)
     * @method
     * @returns void
     */
    static deleteAuthorization(authorization: Authorization): Promise<void>;
    /**
     * Save Authorization.
     * @async
     * @param authorization: Authorization (object to create)
     * @method
     * @returns string id of authorization saved / created
     */
    static saveAuthorization(authorization: Authorization): Promise<string | undefined>;
    /**
     * Find all projects.
     * @async
     * @param sort: { attributes: string[], directions: (boolean | 'asc' | 'desc')[]}
     * @method
     * @returns Authorization - returns promise with Array of projects
     */
    static findAllProjects(sort?: Sort): Promise<Array<Project> | undefined>;
    /**
     * Find project by id.
     * @async
     * @param id: string (id of project to find)
     * @method
     * @returns Project - returns promise with project
     */
    static findProject(id: string): Promise<Project | undefined>;
    static findAllStructs(): Promise<Array<Struct> | undefined>;
    /**
     * Find struct by id.
     * @async
     * @param id: string (id of struct to find)
     * @method
     * @returns Struct - returns promise with Struct
     */
    static findStruct(id: string): Promise<Struct | undefined>;
    /**
     * Find Struct Content by id.
     * @async
     * @param id: string (id of struct to find content)
     * @method
     * @returns any - returns promise with Struct Content
     */
    static findStructFileContentById(id: string): Promise<any | undefined>;
    static findAllOrganizationFlows(sort?: Sort, projectionExpression?: string): Promise<Array<Flow> | undefined>;
    static findAllCompanyFlows(sort?: Sort, projectionExpression?: string): Promise<Array<Flow> | undefined>;
    /**
     * Find flow by id.
     * @async
     * @param id: string (id of flow to find)
     * @method
     * @returns Flow - returns promise with flow
     */
    static findCompanyFlow(id: string): Promise<Flow | undefined>;
    /**
     * Find flow by id.
     * @async
     * @param id: string (id of flow to find)
     * @method
     * @returns Flow - returns promise with flow
     */
    static findOrganizationFlow(id: string): Promise<Flow | undefined>;
    /**
     * Save Flow.
     * @async
     * @param flow: Flow (object to create or save)
     * @method
     * @returns string id of flow saved / created
     */
    static saveFlow(flow: Flow): Promise<string | undefined>;
    /**
     * Get embedded stage
     * @returns stage of embedded
     */
    static getEmbeddedStage(forceLoad?: boolean): Promise<Stage>;
    /**
     * Get embedded project
     * @returns project of embedded
     */
    static getEmbeddedProject(forceLoad?: boolean): Promise<Project>;
    /**
     * Publish flow.
     * @async
     * @param flowId: String (id of flow to publish)
     * @method
     * @returns void
     */
    static publishFlow(flowId: string | undefined): Promise<void>;
    /**
     * Unpublish flow.
     * @async
     * @param flowId: String (id of flow to unpublish)
     * @param historyId: String (id of history to unpublish)
     * @method
     * @returns void
     */
    static unpublishFlow(flowId: string | undefined, historyId: string | undefined): Promise<void>;
    /**
     * Save Flow and Publish flow.
     * @async
     * @param flow: Flow (object to save and publish)
     * @method
     * @returns string id of flow created and published
     */
    static saveAndPublishFlow(flow: Flow): Promise<string | undefined>;
}
declare const _default: {
    ApipassSDK: typeof ApipassSDK;
    Authorization: typeof Authorization;
    Company: typeof Company;
    Organization: typeof Organization;
    Project: typeof Project;
    Struct: typeof Struct;
    Common: typeof Common;
    Custom: typeof Custom;
    Flow: typeof Flow;
    Stage: typeof Stage;
    Step: typeof Step;
    NextStep: typeof NextStep;
    PreviousStep: typeof PreviousStep;
    Sort: typeof Sort;
};
export default _default;
//# sourceMappingURL=apipass-api-js-sdk.d.ts.map